**Example 1: 获取机器地域列表**



Input: 

```
tccli cwp DescribeMachineRegions --cli-unfold-argument ```

Output: 
```
{
    "Response": {
        "CVM": [
            {
                "Region": "ap-guangzhou",
                "RegionName": "华南地区（广州）",
                "RegionId": "1",
                "RegionCode": "gz",
                "RegionNameEn": "South China (Guangzhou)"
            }
        ],
        "BM": [
            {
                "Region": "ap-guangzhou",
                "RegionName": "华南地区（广州）",
                "RegionId": "1",
                "RegionCode": "gz",
                "RegionNameEn": "South China (Guangzhou)"
            }
        ],
        "LH": [
            {
                "Region": "ap-guangzhou",
                "RegionName": "华南地区（广州）",
                "RegionId": "1",
                "RegionCode": "gz",
                "RegionNameEn": "South China (Guangzhou)"
            }
        ],
        "ECM": [
            {
                "Region": "ap-guangzhou",
                "RegionName": "华南地区（广州）",
                "RegionId": "1",
                "RegionCode": "gz",
                "RegionNameEn": "South China (Guangzhou)"
            }
        ],
        "Other": [
            {
                "Region": "ap-others",
                "RegionName": "其他地域（其他）",
                "RegionId": "47",
                "RegionCode": "others",
                "RegionNameEn": "South China (Guangzhou)"
            }
        ],
        "ALL": [
            {
                "Region": "ap-guangzhou",
                "RegionName": "华南地区（广州）",
                "RegionId": "1",
                "RegionCode": "gz",
                "RegionNameEn": "South China (Guangzhou)"
            }
        ],
        "RequestId": "3d4ffdf0-f350-c3ea-d09c-3f5313e044fd"
    }
}
```

